@@ -4,7 +4,6 @@ import (
 	"fmt"
 	"html"
 	"log"
-	"reflect"
 	"regexp"
 	"strconv"
 	"strings"
@@ -19,7 +18,7 @@ import (
 // HTMLWriter exports an org document into a html document.
 type HTMLWriter struct {
 	ExtendingWriter     Writer
-	HighlightCodeBlock  func(source, lang string, inline bool) string
+	HighlightCodeBlock  func(source, lang string, inline bool, params map[string]string) string
 	PrettyRelativeLinks bool
 
 	strings.Builder
@@ -35,20 +34,20 @@ type footnotes struct {
 }
 
 var emphasisTags = map[string][]string{
-	"/":   []string{"<em>", "</em>"},
-	"*":   []string{"<strong>", "</strong>"},
-	"+":   []string{"<del>", "</del>"},
-	"~":   []string{"<code>", "</code>"},
-	"=":   []string{`<code class="verbatim">`, "</code>"},
-	"_":   []string{`<span style="text-decoration: underline;">`, "</span>"},
-	"_{}": []string{"<sub>", "</sub>"},
-	"^{}": []string{"<sup>", "</sup>"},
+	"/":   {"<em>", "</em>"},
+	"*":   {"<strong>", "</strong>"},
+	"+":   {"<del>", "</del>"},
+	"~":   {"<code>", "</code>"},
+	"=":   {`<code class="verbatim">`, "</code>"},
+	"_":   {`<span style="text-decoration: underline;">`, "</span>"},
+	"_{}": {"<sub>", "</sub>"},
+	"^{}": {"<sup>", "</sup>"},
 }
 
 var listTags = map[string][]string{
-	"unordered":   []string{"<ul>", "</ul>"},
-	"ordered":     []string{"<ol>", "</ol>"},
-	"descriptive": []string{"<dl>", "</dl>"},
+	"unordered":   {"<ul>", "</ul>"},
+	"ordered":     {"<ol>", "</ol>"},
+	"descriptive": {"<dl>", "</dl>"},
 }
 
 var listItemStatuses = map[string]string{
@@ -66,7 +65,7 @@ func NewHTMLWriter() *HTMLWriter {
 		document:   &Document{Configuration: defaultConfig},
 		log:        defaultConfig.Log,
 		htmlEscape: true,
-		HighlightCodeBlock: func(source, lang string, inline bool) string {
+		HighlightCodeBlock: func(source, lang string, inline bool, params map[string]string) string {
 			if inline {
 				return fmt.Sprintf("<div class=\"highlight-inline\">\n<pre>\n%s\n</pre>\n</div>", html.EscapeString(source))
 			}
@@ -100,7 +99,17 @@ func (w *HTMLWriter) Before(d *Document) {
 	if title := d.Get("TITLE"); title != "" && w.document.GetOption("title") != "nil" {
 		titleDocument := d.Parse(strings.NewReader(title), d.Path)
 		if titleDocument.Error == nil {
-			title = w.WriteNodesAsString(titleDocument.Nodes...)
+			simpleTitle := false
+			if len(titleDocument.Nodes) == 1 {
+				switch p := titleDocument.Nodes[0].(type) {
+				case Paragraph:
+					simpleTitle = true
+					title = w.WriteNodesAsString(p.Children...)
+				}
+			}
+			if !simpleTitle {
+				title = w.WriteNodesAsString(titleDocument.Nodes...)
+			}
 		}
 		w.WriteString(fmt.Sprintf(`<h1 class="title">%s</h1>`+"\n", title))
 	}
@@ -129,7 +138,7 @@ func (w *HTMLWriter) WriteBlock(b Block) {
 		if len(b.Parameters) >= 1 {
 			lang = strings.ToLower(b.Parameters[0])
 		}
-		content = w.HighlightCodeBlock(content, lang, false)
+		content = w.HighlightCodeBlock(content, lang, false, params)
 		w.WriteString(fmt.Sprintf("<div class=\"src src-%s\">\n%s\n</div>\n", lang, content))
 	case "EXAMPLE":
 		w.WriteString(`<pre class="example">` + "\n" + html.EscapeString(content) + "\n</pre>\n")
@@ -152,6 +161,11 @@ func (w *HTMLWriter) WriteBlock(b Block) {
 	}
 }
 
+func (w *HTMLWriter) WriteLatexBlock(b LatexBlock) {
+	WriteNodes(w, b.Content...)
+	w.WriteString("\n")
+}
+
 func (w *HTMLWriter) WriteResult(r Result) { WriteNodes(w, r.Node) }
 
 func (w *HTMLWriter) WriteInlineBlock(b InlineBlock) {
@@ -159,7 +173,7 @@ func (w *HTMLWriter) WriteInlineBlock(b InlineBlock) {
 	switch b.Name {
 	case "src":
 		lang := strings.ToLower(b.Parameters[0])
-		content = w.HighlightCodeBlock(content, lang, true)
+		content = w.HighlightCodeBlock(content, lang, true, nil)
 		w.WriteString(fmt.Sprintf("<div class=\"src src-inline src-%s\">\n%s\n</div>", lang, content))
 	case "export":
 		if strings.ToLower(b.Parameters[0]) == "html" {
@@ -376,14 +390,14 @@ func (w *HTMLWriter) WriteRegularLink(l RegularLink) {
 		if l.Description == nil {
 			w.WriteString(fmt.Sprintf(`<img src="%s" alt="%s" title="%s" />`, url, url, url))
 		} else {
-			description := strings.TrimPrefix(String(l.Description), "file:")
+			description := strings.TrimPrefix(String(l.Description...), "file:")
 			w.WriteString(fmt.Sprintf(`<a href="%s"><img src="%s" alt="%s" /></a>`, url, description, description))
 		}
 	case "video":
 		if l.Description == nil {
 			w.WriteString(fmt.Sprintf(`<video src="%s" title="%s">%s</video>`, url, url, url))
 		} else {
-			description := strings.TrimPrefix(String(l.Description), "file:")
+			description := strings.TrimPrefix(String(l.Description...), "file:")
 			w.WriteString(fmt.Sprintf(`<a href="%s"><video src="%s" title="%s"></video></a>`, url, description, description))
 		}
 	default:
@@ -613,7 +627,7 @@ func setHTMLAttribute(attributes []h.Attribute, k, v string) []h.Attribute {
 
 func isParagraphNodeSlice(ns []Node) bool {
 	for _, n := range ns {
-		if reflect.TypeOf(n).Name() != "Paragraph" {
+		if _, ok := n.(Paragraph); !ok {
 			return false
 		}
 	}
